@@ -43,7 +43,7 @@ public:
     void addItem(const QIcon &icon, const QString &text);
     void addItems(const QStringList &texts);
 
-    int currentIndex() const;
+    Q_REQUIRED_RESULT int currentIndex() const;
 
 Q_SIGNALS:
     void rightPressed();
@@ -60,7 +60,7 @@ protected:
 
 private:
     void slotActionTriggered();
-    QMenu *mMenu;
+    QMenu *mMenu = nullptr;
     QVector<QPair<QString, QIcon> > mList;
     int mCurrentIndex;
 };
@@ -122,8 +122,7 @@ public:
 
 Q_SIGNALS:
     void changed();
-    void changed(const KCalCore::Attendee::Ptr &oldAttendee,
-                 const KCalCore::Attendee::Ptr &newAttendee);
+    void changed(const KCalCore::Attendee::Ptr &oldAttendee, const KCalCore::Attendee::Ptr &newAttendee);
     void editingFinished(KPIM::MultiplyingLine *);
 
 private:
@@ -133,10 +132,10 @@ private:
     void dataFromFields();
     void fieldsFromData();
 
-    AttendeeComboBox *mRoleCombo;
-    AttendeeComboBox *mStateCombo;
-    AttendeeComboBox *mResponseCombo;
-    AttendeeLineEdit *mEdit;
+    AttendeeComboBox *mRoleCombo = nullptr;
+    AttendeeComboBox *mStateCombo = nullptr;
+    AttendeeComboBox *mResponseCombo = nullptr;
+    AttendeeLineEdit *mEdit = nullptr;
     QSharedPointer<AttendeeData> mData;
     QString mUid;
     bool mModified;
